# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit/chaostoolkit-addons/compare/0.1.1...HEAD

## [0.1.1][]

[0.1.1]: https://github.com/chaostoolkit/chaostoolkit-addons/compare/0.1.0...0.1.1

### Added

-   MANIFEST.in

## [0.1.0][]

[0.1.0]: https://github.com/chaostoolkit/chaostoolkit-addons/tree/0.1.0

### Added

-   Initial release